<?php

/**
 * The plugin bootstrap file
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://easytranslate.com
 * @since             1.0.0
 * @package           Easy_Translate
 * @wordpress-plugin
 * Plugin Name:       EasyTranslate
 * Plugin URI:        https://www.easytranslate.com/en/integrations/cms/wordpress-plugin/
 * Description:       This is a short description of what the plugin does. It's displayed in the WordPress admin area.
 * Version:           1.10.3
 * Author:            EasyTranslate
 * Author URI:        https://easytranslate.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       easy-translate
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if (!defined('WPINC')) {
    die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define('EASY_TRANSLATE_VERSION', '1.10.3');

/**
 * The plugin slug.
 */
define('EASY_TRANSLATE', 'easy-translate');

/**
 * The root path of the plugin.
 */
define('EASY_TRANSLATE_ROOT', plugin_dir_path(__FILE__));

/**
 * The name of an option to sanitize and save.
 */
define('EASY_TRANSLATE_INTEGRATION_OPTION', 'easy_translate_api_integration');

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-easy-translate-activator.php
 */
function activate_easy_translate()
{
    require_once EASY_TRANSLATE_ROOT . 'includes/class-easy-translate-activator.php';
    Easy_Translate_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-easy-translate-deactivator.php
 */
function deactivate_easy_translate()
{
    require_once EASY_TRANSLATE_ROOT . 'includes/class-easy-translate-deactivator.php';
    Easy_Translate_Deactivator::deactivate();
}

register_activation_hook(__FILE__, 'activate_easy_translate');
register_deactivation_hook(__FILE__, 'deactivate_easy_translate');

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require EASY_TRANSLATE_ROOT . 'includes/class-easy-translate.php';

/**
 * Begins execution of the plugin.
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 */
function run_easy_translate()
{

    $plugin = new Easy_Translate();
    $plugin->run();

}

run_easy_translate();
